.. ludology documentation master file, created by
   sphinx-quickstart on Tue May 22 17:04:12 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ludology: the study of Games
============================

.. note::

   We use the term Game (capital G) to refer to a mathematical object defined below, and the term game (lower case) to refer to particular games such as Amazons, Domineering, or Hackenbush.

This package is for the study of Games, mathematical abstractions for the analysis of partizan games.

A partizan game is one such that:

* there are two players, Left and Right, who alternate turns
* there are no random elements (dice, shuffled cards, etc)
* there is no sequence of play which causes the state of the game to repeat
* if it is a player's turn and they are unable to move, they lose

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   content/games
   content/surreals
   content/nimbers
   content/thermography



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
